/***********************************************************************************************************************************
Harness for Fd Testing
***********************************************************************************************************************************/

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Install/uninstall shim
void hrnFdReadyShimInstall(void);
void hrnFdReadyShimUninstall(void);

// Use shim for one call
void hrnFdReadyShimOne(bool result);
